
module Agda.ImpossibleTest where

import Agda.Utils.Impossible

impossibleTest :: a
impossibleTest = __IMPOSSIBLE__
